#!/bin/sh
#############################################################################
#                                                                           #
# LV.sh  : Script to run wave model end to end for Lake Victoria.           #
#                                                                           #
# Grids available in this test :                                            #
#                                                                           #
#  LV_sm  : 10' resolution grid.                                            #
#  LV_md  : 2.4' resolution grid.                                           #
#  LV_lg  : 1.2' resolution grid.                                           #
#                                                                           #
#  Remarks :                                                                #
#                                             Hendrik Tolman, Jan. 2012     #
#                                                                           #
#    Copyright 2012-2013 National Weather Service (NWS),                    #
#       National Oceanic and Atmospheric Administration.  All rights        #
#       reserved.  WAVEWATCH III is a trademark of the NWS.                 #
#       No unauthorized use without permission.                             #
#                                                                           #
#############################################################################

# 0. Preparations -----------------------------------------------------------

  set -e

  grid='LV_sm'             # Choose one of the three grids
  wind='yes'               # Yes: run with CFS winds data
                           # No : run with homogeneous winds

  t_beg='20091111 000000'  # Starting time of run
  t_end='20091112 000000'  # Ending time of run
  t_rst='20091112 000000'  # Time for restart file, if empty no restart file
# t_rst=                   # Time for restart file, if empty no restart file

cat > buoy.all << EOF
    33.50  0.00 'EQ        '
    33.00 -1.00 'Center    '
    32.25 -2.00 'South     '
EOF

# 0.a Process restarting

  if [ -z "$t_rst" ] ; then
    dt_rst='0'
    t_rst=$t_end
  else
    dt_rst='1'
    rdate=`echo $t_rst | awk '{ print $1 }'`
    rtime=`echo $t_rst | awk '{ print $2 }'`
  fi

# 0.b Clean-up

  echo ' ' ; echo ' '
  echo '                  ======> TEST RUN WAVEWATCH III <====== '
  echo '                    ==================================   '
  echo '                              Running Lake Victoria model'
  echo ' '

# 1. Grid pre-processor -----------------------------------------------------

  echo ' '
  echo '+--------------------+'
  echo '|  Grid preprocessor |'
  echo '+--------------------+'
  echo ' '

  rm -f mod_def.* ww3_grid.inp

  ln -s ww3_grid.$grid ww3_grid.inp

  echo "   Screen ouput routed to ww3_grid.$grid.out"
  ww3_grid > ww3_grid.$grid.out

  rm -f ww3_grid.inp

# 2. Initial conditions -----------------------------------------------------

  echo ' '
  echo '+--------------------+'
  echo '| Initial conditions |'
  echo '+--------------------+'
  echo ' '

  idate=`echo $t_beg | awk '{ print $1 }'`
  itime=`echo $t_beg | awk '{ print $2 }'`

  if [ -f restarts/restart.$grid.$idate.$itime ]
  then

     echo "   Using saved restart restart.$grid.$idate.$itime ..."
     cp restarts/restart.$grid.$idate.$itime restart.ww3

  else

    echo "   Screen ouput routed to ww3_strt.out"
    ww3_strt > ww3_strt.out

  fi

# 3. Input fields -----------------------------------------------------------

  if [ "$wind" = 'yes' ]
  then
    FLHW='F'
    echo ' '
    echo '+--------------------+'
    echo '| Input data         |'
    echo '+--------------------+'
    echo ' '

    echo '   Generating input wind fields ...'

    echo "   Screen ouput routed to ww3_prep.out"
    ww3_prep > ww3_prep.out
  else
    FLHW='T'
  fi

# 4. Main program -----------------------------------------------------------

  echo ' '
  echo '+--------------------+'
  echo '|    Main program    |'
  echo '+--------------------+'
  echo ' '

cat > ww3_shel.inp << EOF
$ -------------------------------------------------------------------- $
$ WAVEWATCH III shell input file                                       $
$ -------------------------------------------------------------------- $
$
   F F     Water levels
   F F     Currents
   T $FLHW     Winds
   F       Ice concentrations
   F       Assimilation data : Mean parameters
   F       Assimilation data : 1-D spectra
   F       Assimilation data : 2-D spectra.
$
   $t_beg
   $t_end
$
   1
$
   $t_beg  3600  $t_end
$ ---------------------------------------------------------------
$ D C W D W  I H L T T  T C F D S  D P P P P  P P W P D  F C C U C
$ P U N T L  C S   0    M G P I P  P H T L T  S W S N T  C F F S H
$ T R D   V  E     2    1 E   R R    S P P H  I S F R D    X D T A
$ ---------------------------------------------------------------
  T F T F T  F T T T T  T T T T T  T T T T T  T T T T T  F F F F F
  F F F F F  F F F F F  F F F F F  F F F F F  F F F
$ ---------------------------------------------------------------
$ F T T W W  W W A U B  F T S T J  F T U M M  P U U
$ A A W C C  C C B B E  B B X W    O U S S S  2 S S
$ W W A C F  H M R R D  B B Y O    C S S S C  S 1 2
$ ---------------------------------------------------------------
   $t_beg  3600  $t_end
EOF
cat buoy.all >> ww3_shel.inp
cat >> ww3_shel.inp << EOF
     0.0   0.0  'STOPSTRING'
   $t_beg     0  $t_end
   $t_rst     $dt_rst  $t_rst
   $t_beg     0  $t_end
   $t_beg     0  $t_end
$
$  'LEV' 20091101 000000  -10.0
   'WND' 20091101 000000    9.5   145.    2.0
   'STP'
$
$ -------------------------------------------------------------------- $
$ End of input file                                                    $
$ -------------------------------------------------------------------- $
EOF

# echo "   Screen ouput routed to ww3_shel.out"

  ww3_shel # > ww3_shel.out

# rm -f fort.* ww3_shel.inp test*

  if [ -f restart001.ww3 ] ; then
    mkdir -p restarts
    echo "   Saving restart001.ww3 as restart.$grid.$rdate.$rtime"
    echo "      in restarts ..."
    mv restart001.ww3 restarts/restart.$grid.$rdate.$rtime
  fi

# 4. Gridded output ---------------------------------------------------------

  echo ' '
  echo '+--------------------+'
  echo '|   Gridded output   |'
  echo '+--------------------+'
  echo ' '

cat > gx_outf.inp << EOF
$ -------------------------------------------------------------------- $
$ WAVEWATCH III Grid output post-processing ( GrADS )                  $
$ -------------------------------------------------------------------- $
$
  $t_beg  3600. 999
$
$ ---------------------------------------------------------------
$ D C W D W  I H L T T  T C F D S  D P P P P  P P W P D  F C C U C
$ P U N T L  C S   0    M G P I P  P H T L T  S W S N T  C F F S H
$ T R D   V  E     2    1 E   R R    S P P H  I S F R D    X D T A
$ ---------------------------------------------------------------
  T F T F T  F T T T T  T T T T T  T T T T T  T T T T T  F F F F F
  F F F F F  F F F F F  F F F F F  F F F F F  F F F
$ ---------------------------------------------------------------
$ F T T W W  W W A U B  F T S T J  F T U M M  P U U
$ A A W C C  C C B B E  B B X W    O U S S S  2 S S
$ W W A C F  H M R R D  B B Y O    C S S S C  S 1 2
$ ---------------------------------------------------------------
$
  0 999 0 999  T T
$
$ -------------------------------------------------------------------- $
$ End of input file                                                    $
$ -------------------------------------------------------------------- $
EOF

  echo "   GrADS field data ..."
  echo "      Screen ouput routed to gx_outf.out"

  gx_outf > gx_outf.out

# 5. Point output -----------------------------------------------------------
    
  echo ' '
  echo '+--------------------+'
  echo '|    Point output    |'
  echo '+--------------------+'
  echo ' '
  
cat > gx_outp.inp << EOF
$ -------------------------------------------------------------------- $
$ WAVEWATCH III Point output post-processing ( GrADS )                 $
$ -------------------------------------------------------------------- $
$
  $t_beg  3600. 999
$
  1
 -1
$
  T T T T T T 
$
$ -------------------------------------------------------------------- $
$ End of input file                                                    $
$ -------------------------------------------------------------------- $
EOF

  echo "   GrADS point data ..."
  echo "      Screen ouput routed to gx_outp.out"

  gx_outp > gx_outp.out

# 6. End, cleaning up -------------------------------------------------------

  echo ' ' ; echo "Cleaning-up `pwd`"
# rm -f *.ww3

  echo ' ' ; echo ' '
  echo '                  ======>  END OF WAVEWATCH III  <====== '
  echo '                    ==================================   '
  echo ' '

# End of LV.sh --------------------------------------------------------------
